@@ -19,7 +19,6 @@ makeCostSensTask = function(id = deparse(substitute(data)), data, costs, blockin
       colnames(costs) = stri_paste("y", seq_col(costs))
   }
   task = makeSupervisedTask("costsens", data, target, weights, blocking, fixup.data = fixup.data, check.data = check.data)
-  task$env$costs = costs
 
   if (check.data) {
     assertMatrix(costs, any.missing = FALSE, col.names = "strict")
@@ -31,14 +30,15 @@ makeCostSensTask = function(id = deparse(substitute(data)), data, costs, blockin
       stopf("The name '..y..' is currently reserved for costsens tasks. You can use it neither for features nor labels!")
   }
 
-  task$task.desc = makeTaskDesc.CostSensTask(task, id, target)
+  task$task.desc = makeCostSensTaskDesc(id, data, target, blocking, costs)
   addClasses(task, "CostSensTask")
 }
 
-makeTaskDesc.CostSensTask = function(task, id, target) {
-  td = makeTaskDescInternal(task, "costsens", id, target)
-  td$class.levels = colnames(task$env$costs)
-  return(addClasses(td, c("TaskDescCostSens", "TaskDescSupervised")))
+makeCostSensTaskDesc = function(id, data, target, blocking, costs) {
+  td = makeTaskDescInternal("costsens", id, data, target, weights = NULL, blocking = blocking)
+  td$class.levels = colnames(costs)
+  td$costs = costs
+  return(addClasses(td, c("CostSensTaskDesc", "SupervisedTaskDesc")))
 }
 
 #' @export
