@@ -95,5 +95,19 @@ predictLearner.FilterWrapper = function(.learner, .model, .newdata, ...) {
 #' @export
 #' @family filter
 getFilteredFeatures = function(model) {
+  UseMethod("getFilteredFeatures")
+}
+
+#' @export
+getFilteredFeatures.default = function(model) {
+  if (is.null(model$learner.model$next.model)) {
+    NULL
+  } else {
+    getFilteredFeatures(model$learner.model$next.model)
+  }
+}
+
+#' @export
+getFilteredFeatures.FilterModel = function(model) {
   model$learner.model$next.model$features
 }
