@@ -4,19 +4,18 @@ makeRLearner.classif.IBk = function() {
     cl = "classif.IBk",
     package = "RWeka",
     par.set = makeParamSet(
-      makeLogicalLearnerParam(id = "I"),
-      makeLogicalLearnerParam(id = "F"),
+      makeLogicalLearnerParam(id = "I", default = FALSE),
+      makeLogicalLearnerParam(id = "F", default = FALSE),
       makeIntegerLearnerParam(id = "K", lower = 1L, default = 1L),
-      makeLogicalLearnerParam(id = "E"),
+      makeLogicalLearnerParam(id = "E", default = FALSE),
       makeIntegerLearnerParam(id = "W", lower = 0L),
-      makeLogicalLearnerParam(id = "X"),
+      makeLogicalLearnerParam(id = "X", default = FALSE),
       makeUntypedLearnerParam(id = "A", default = "weka.core.neighboursearch.LinearNNSearch"),
       makeLogicalLearnerParam(id = "output-debug-info", default = FALSE, tunable = FALSE)
     ),
     properties = c("twoclass", "multiclass", "numerics", "factors", "prob"),
     name = "k-Nearest Neighbours",
-    short.name = "ibk",
-    note = ""
+    short.name = "ibk"
   )
 }
 
