@@ -14,8 +14,7 @@ makeRLearner.classif.LiblineaRL1LogReg = function() {
     properties = c("twoclass", "multiclass", "numerics", "class.weights", "prob"),
     class.weights.param = "wi",
     name = "L1-Regularized Logistic Regression",
-    short.name = "liblinl1logreg",
-    note = ""
+    short.name = "liblinl1logreg"
   )
 }
 
@@ -27,7 +26,7 @@ trainLearner.classif.LiblineaRL1LogReg = function(.learner, .task, .subset, .wei
 
 #' @export
 predictLearner.classif.LiblineaRL1LogReg = function(.learner, .model, .newdata, ...) {
-  if(.learner$predict.type == "response")
+  if (.learner$predict.type == "response")
     as.factor(predict(.model$learner.model, newx = .newdata, ...)$predictions)
   else
     predict(.model$learner.model, newx = .newdata, proba = TRUE, ...)$probabilities
