@@ -14,8 +14,7 @@ makeRLearner.classif.LiblineaRMultiClassSVC = function() {
     properties = c("twoclass", "multiclass", "numerics", "class.weights"),
     class.weights.param = "wi",
     name = "Support Vector Classification by Crammer and Singer",
-    short.name = "liblinmulticlasssvc",
-    note = ""
+    short.name = "liblinmulticlasssvc"
   )
 }
 
