@@ -5,6 +5,7 @@ makeRLearner.classif.clusterSVM = function() {
     package = c("SwarmSVM", "LiblineaR"),
     par.set = makeParamSet(
       makeIntegerLearnerParam(id = "centers", default = 2, lower = 1),
+      # FIXME default for centers of clusterSVM is NULL
       makeUntypedLearnerParam(id = "cluster.object", default = NULL, requires = quote(is.null(centers))),
       makeNumericLearnerParam(id = "lambda", default = 1, lower = 0),
       makeLogicalLearnerParam(id = "sparse", default = TRUE),
@@ -34,8 +35,7 @@ makeRLearner.classif.clusterSVM = function() {
 #' @export
 trainLearner.classif.clusterSVM = function(.learner, .task, .subset, .weights = NULL, ...) {
   d = getTaskData(.task, .subset, target.extra = TRUE)
-  pars = list(...)
-    SwarmSVM::clusterSVM(x = d$data, y = d$target, ...)
+  SwarmSVM::clusterSVM(x = d$data, y = d$target, ...)
 }
 
 #' @export
