@@ -32,7 +32,7 @@ trainLearner.classif.h2o.gbm = function(.learner, .task, .subset, .weights = NUL
   x = getTaskFeatureNames(.task)
   d = getTaskData(.task, subset = .subset)
   h2of = h2o::as.h2o(d)
-  distribution = ifelse(length(getTaskDescription(.task)$class.levels) == 2L, "bernoulli", "multinomial")
+  distribution = ifelse(length(getTaskDesc(.task)$class.levels) == 2L, "bernoulli", "multinomial")
   h2o::h2o.gbm(y = y, x = x, training_frame = h2of, distribution = distribution, ...)
 }
 
