@@ -28,8 +28,8 @@ makeRLearner.classif.ksvm = function() {
       makeNumericLearnerParam(id = "tol", default = 0.001, lower = 0),
       makeLogicalLearnerParam(id = "shrinking", default = TRUE),
       makeNumericVectorLearnerParam(id = "class.weights", len = NA_integer_, lower = 0),
-      makeLogicalLearnerParam(id = "fit", default = TRUE),
-      makeIntegerLearnerParam(id = "cache", default = 40L, lower = 1L, tunable = FALSE)
+      makeLogicalLearnerParam(id = "fit", default = TRUE, tunable = FALSE),
+      makeIntegerLearnerParam(id = "cache", default = 40L, lower = 1L)
     ),
     par.vals = list(fit = FALSE),
     properties = c("twoclass", "multiclass", "numerics", "factors", "prob", "class.weights"),
