@@ -4,7 +4,9 @@ makeRLearner.classif.plsdaCaret = function() {
     package = "caret",
     par.set = makeParamSet(
       makeIntegerLearnerParam(id = "ncomp", default = 2, lower = 1),
-      makeDiscreteLearnerParam(id = "probMethod", values = c("softmax", "Bayes"), default = "softmax")
+      makeDiscreteLearnerParam(id = "probMethod", values = c("softmax", "Bayes"), default = "softmax"),
+      makeDiscreteLearnerParam(id = "method", default = "kernelpls",
+                               values = c("kernelpls", "widekernelpls", "simpls", "oscorespls"))
     ),
     properties = c("numerics", "prob", "twoclass"),
     name = "Partial Least Squares (PLS) Discriminant Analysis",
@@ -15,7 +17,7 @@ makeRLearner.classif.plsdaCaret = function() {
 #' @export
 trainLearner.classif.plsdaCaret = function(.learner, .task, .subset, .weights, ...) {
   d = getTaskData(.task, .subset, target.extra = TRUE)
-  caret::plsda(d$data, d$target, method = "oscorespls", ...)
+  caret::plsda(d$data, d$target, ...)
 }
 
 #' @export
