@@ -3,18 +3,23 @@ makeRLearner.classif.probit = function() {
   makeRLearnerClassif(
     cl = "classif.probit",
     package = "stats",
-    par.set = makeParamSet(),
+    par.set = makeParamSet(
+      makeLogicalLearnerParam("model", default = TRUE, tunable = FALSE)
+    ),
+    par.vals = list(
+      model = FALSE
+    ),
     properties = c("twoclass", "numerics", "factors", "prob", "weights"),
     name = "Probit Regression",
     short.name = "probit",
-    note = 'Delegates to `glm` with `family = binomial(link = "probit")`.'
+    note = "Delegates to `glm` with `family = binomial(link = 'probit')`. We set 'model' to FALSE by default to save memory."
   )
 }
 
 #' @export
 trainLearner.classif.probit = function(.learner, .task, .subset, .weights = NULL,  ...) {
   f = getTaskFormula(.task)
-  stats::glm(f, data = getTaskData(.task, .subset), model = FALSE,
+  stats::glm(f, data = getTaskData(.task, .subset),
     family = binomial(link = "probit"), weights = .weights, ...)
 }
 
