@@ -4,7 +4,7 @@ makeRLearner.classif.rknn = function(){
     cl = "classif.rknn",
     package = "rknn",
     par.set = makeParamSet(
-      makeIntegerLearnerParam(id = "k", default = 1L, lower = 1L),
+      makeIntegerLearnerParam(id = "k", default = 1L, lower = 1L, upper = 98L),
       makeIntegerLearnerParam(id = "r", default = 500L, lower = 1L),
       makeIntegerLearnerParam(id = "mtry", lower = 1L),
       makeIntegerLearnerParam(id = "seed", lower = 1L),
@@ -14,7 +14,7 @@ makeRLearner.classif.rknn = function(){
     properties = c("twoclass", "multiclass", "numerics", "ordered"),
     name = "Random k-Nearest-Neighbors",
     short.name = "rknn",
-    note =""
+    note = "k restricted to < 99 as the code allocates arrays of static size"
   )
 }
 
