@@ -17,7 +17,8 @@ makeRLearner.regr.earth = function() {
       makeNumericLearnerParam(id = "fast.beta", default = 1),
       makeDiscreteLearnerParam(id = "pmethod", default = "backward",
         values = c("backward", "none", "exhaustive", "forward", "seqrep", "cv")),
-      makeIntegerLearnerParam(id = "nprune")
+      makeIntegerLearnerParam(id = "nprune"),
+      makeIntegerLearnerParam(id = "nfold", default = 0L, requires = quote(pmethod == "cv"))
     ),
     properties = c("numerics", "factors"),
     name = "Multivariate Adaptive Regression Splines",
