@@ -41,7 +41,7 @@ makeRLearner.regr.randomForestSRC = function() {
       makeLogicalLearnerParam(id = "tree.err", default = FALSE, tunable = FALSE)
     ),
     par.vals = list(na.action = "na.impute"),
-    properties = c("missings", "numerics", "factors", "ordered", "weights", "featimp"),
+    properties = c("missings", "numerics", "factors", "ordered", "weights", "oobpreds", "featimp"),
     name = "Random Forest",
     short.name = "rfsrc",
     note = '`na.action` has been set to `"na.impute"` by default to allow missing data support.'
@@ -62,6 +62,10 @@ predictLearner.regr.randomForestSRC = function(.learner, .model, .newdata, ...)
 }
 
 #' @export
+getOOBPredsLearner.regr.randomForestSRC = function(.learner, .model) {
+  as.numeric(.model$learner.model$predicted.oob)
+}
+
 #' @rdname getFeatureImportanceLearner
 getFeatureImportanceLearner.regr.randomForestSRC = function(.learner, .model, ...) {
   mod = getLearnerModel(.model)
