@@ -5,6 +5,7 @@ makeRLearner.regr.rsm = function() {
     package = "rsm",
     par.set = makeParamSet(
       makeDiscreteLearnerParam(id = "modelfun", default = "FO", values = c("FO", "TWI", "SO"))
+      # FIXME rsm() seems to have no default as one expression is needed for the formula, if there is a default, par.vals is redundant
     ),
     par.vals = list(modelfun = "FO"),
     properties = c("numerics"),
@@ -17,15 +18,15 @@ makeRLearner.regr.rsm = function() {
 #' @export
 trainLearner.regr.rsm = function(.learner, .task, .subset, .weights = NULL,  ...) {
   mf = list(...)$modelfun
-  vs = paste(getTaskFeatureNames(.task), collapse = ",")
-  g = function(x) paste(x, "(", vs, ")", sep = "")
+  vs = stri_paste(getTaskFeatureNames(.task), collapse = ",", sep = " ")
+  g = function(x) stri_paste(x, "(", vs, ")", sep = "")
   mf = switch(mf,
     FO = g("FO"),
-    TWI = paste(g("TWI"), "+", g("FO")),
+    TWI = stri_paste(g("TWI"), "+", g("FO"), sep = " "),
     SO = g("SO"),
     stop("Unknown modelfun: ", mf)
   )
-  f = as.formula(paste(getTaskTargetNames(.task), "~", mf))
+  f = as.formula(stri_paste(getTaskTargetNames(.task), "~", mf, sep = " "))
   myargs = list(f, getTaskData(.task, .subset))
   # strange behaviour in rsm forces us to use do.call...
   do.call(rsm::rsm, myargs)
