@@ -36,7 +36,11 @@ makeRLearner.surv.glmnet = function() {
     short.name = "glmnet",
     note = "Factors automatically get converted to dummy columns, ordered factors to integer.
       Parameter `s` (value of the regularization parameter used for predictions) is set to `0.1` by default,
-      but needs to be tuned by the user."
+      but needs to be tuned by the user.
+      glmnet uses a global control object for its parameters. mlr resets all control parameters to their defaults
+      before setting the specified parameters and after training.
+      If you are setting glmnet.control parameters through glmnet.control,
+      you need to save and re-set them after running the glmnet learner."
   )
 }
 
@@ -49,10 +53,11 @@ trainLearner.surv.glmnet = function(.learner, .task, .subset, .weights = NULL,
   if (!is.null(.weights))
     args$weights = .weights
 
+  glmnet::glmnet.control(factory = TRUE)
   saved.ctrl = glmnet::glmnet.control()
   is.ctrl.arg = names(args) %in% names(saved.ctrl)
   if (any(is.ctrl.arg)) {
-    on.exit(do.call(glmnet::glmnet.control, saved.ctrl))
+    on.exit(glmnet::glmnet.control(factory = TRUE))
     do.call(glmnet::glmnet.control, args[is.ctrl.arg])
     args = args[!is.ctrl.arg]
   }
