@@ -19,13 +19,16 @@
 #' \item{opt.path [\code{\link[ParamHelpers]{OptPath}}]}{Optimization path which lead to \code{x}.
 #'   Note that when you have trafos on some of your params, the opt.path always contains the
 #'   UNTRANSFORMED values on the original scale. You can simply call \code{trafoOptPath(opt.path)} to
-#'   transform them, or, \code{as.data.frame{trafoOptPath(opt.path)}}}
+#'   transform them, or, \code{as.data.frame{trafoOptPath(opt.path)}}.
+#'   If mlr option \code{on.error.dump} is \code{TRUE}, \code{OptPath} will have a \code{.dump} object
+#'   in its \code{extra} column which contains error dump traces from failed optimization evaluations.
+#'   It can be accessed by \code{getOptPathEl(opt.path)$extra$.dump}.}
 #' }
 #' @name TuneResult
 #' @rdname TuneResult
 NULL
-makeTuneResult = function(learner, control, x, y, threshold, opt.path) {
-  makeOptResult(learner, control, x, y, threshold, opt.path, "TuneResult")
+makeTuneResult = function(learner, control, x, y, threshold, opt.path, ...) {
+  makeOptResult(learner, control, x, y, threshold, opt.path, "TuneResult", ...)
 }
 
 makeTuneResultFromOptPath = function(learner, par.set, measures, control, opt.path) {
