@@ -36,6 +36,7 @@ NULL
 test.mean = makeAggregation(
   id = "test.mean",
   name = "Test mean",
+  properties = "req.test",
   fun = function(task, perf.test, perf.train, measure, group, pred) mean(perf.test)
 )
 
@@ -44,6 +45,7 @@ test.mean = makeAggregation(
 test.sd = makeAggregation(
   id = "test.sd",
   name = "Test sd",
+  properties = "req.test",
   fun = function(task, perf.test, perf.train, measure, group, pred) sd(perf.test)
 )
 
@@ -52,6 +54,7 @@ test.sd = makeAggregation(
 test.median = makeAggregation(
   id = "test.median",
   name = "Test median",
+  properties = "req.test",
   fun = function(task, perf.test, perf.train, measure, group, pred) median(perf.test)
 )
 
@@ -60,6 +63,7 @@ test.median = makeAggregation(
 test.min = makeAggregation(
   id = "test.min",
   name = "Test minimum",
+  properties = "req.test",
   fun = function(task, perf.test, perf.train, measure, group, pred) min(perf.test)
 )
 
@@ -68,6 +72,7 @@ test.min = makeAggregation(
 test.max = makeAggregation(
   id = "test.max",
   name = "Test maximum",
+  properties = "req.test",
   fun = function(task, perf.test, perf.train, measure, group, pred) max(perf.test)
 )
 
@@ -76,6 +81,7 @@ test.max = makeAggregation(
 test.sum = makeAggregation(
   id = "test.sum",
   name = "Test sum",
+  properties = "req.test",
   fun = function(task, perf.test, perf.train, measure, group, pred) sum(perf.test)
 )
 
@@ -84,6 +90,7 @@ test.sum = makeAggregation(
 test.range = makeAggregation(
   id = "test.range",
   name = "Test range",
+  properties = "req.test",
   fun = function(task, perf.test, perf.train, measure, group, pred) diff(range(perf.test))
 )
 
@@ -92,6 +99,7 @@ test.range = makeAggregation(
 test.rmse = makeAggregation(
   id = "test.rmse",
   name = "Test RMSE",
+  properties = "req.test",
   fun = function(task, perf.test, perf.train, measure, group, pred) sqrt(mean(perf.test^2))
 )
 
@@ -100,6 +108,7 @@ test.rmse = makeAggregation(
 train.mean = makeAggregation(
   id = "train.mean",
   name = "Training mean",
+  properties = "req.train",
   fun = function(task, perf.test, perf.train, measure, group, pred) mean(perf.train)
 )
 
@@ -108,6 +117,7 @@ train.mean = makeAggregation(
 train.sd = makeAggregation(
   id = "train.sd",
   name = "Training sd",
+  properties = "req.train",
   fun = function(task, perf.test, perf.train, measure, group, pred) sd(perf.train)
 )
 
@@ -116,6 +126,7 @@ train.sd = makeAggregation(
 train.median = makeAggregation(
   id = "train.median",
   name = "Training median",
+  properties = "req.train",
   fun = function(task, perf.test, perf.train, measure, group, pred) median(perf.train)
 )
 
@@ -124,6 +135,7 @@ train.median = makeAggregation(
 train.min = makeAggregation(
   id = "train.min",
   name = "Training min",
+  properties = "req.train",
   fun = function(task, perf.test, perf.train, measure, group, pred) min(perf.train)
 )
 
@@ -132,6 +144,7 @@ train.min = makeAggregation(
 train.max = makeAggregation(
   id = "train.max",
   name = "Training max",
+  properties = "req.train",
   fun = function(task, perf.test, perf.train, measure, group, pred) max(perf.train)
 )
 
@@ -140,6 +153,7 @@ train.max = makeAggregation(
 train.sum = makeAggregation(
   id = "train.sum",
   name = "Training sum",
+  properties = "req.train",
   fun = function(task, perf.test, perf.train, measure, group, pred) sum(perf.train)
 )
 
@@ -148,6 +162,7 @@ train.sum = makeAggregation(
 train.range = makeAggregation(
   id = "train.range",
   name = "Training range",
+  properties = "req.train",
   fun = function(task, perf.test, perf.train, measure, group, pred) diff(range(perf.train))
 )
 
@@ -156,6 +171,7 @@ train.range = makeAggregation(
 train.rmse = makeAggregation(
   id = "train.rmse",
   name = "Training RMSE",
+  properties = "req.train",
   fun = function(task, perf.test, perf.train, measure, group, pred) sqrt(mean(perf.train^2))
 )
 
@@ -164,6 +180,7 @@ train.rmse = makeAggregation(
 b632 = makeAggregation(
   id = "b632",
   name = ".632 Bootstrap",
+  properties = c("req.train", "req.test"),
   fun = function(task, perf.test, perf.train, measure, group, pred) {
     mean(0.632*perf.test + 0.368*perf.train)
   }
@@ -176,6 +193,7 @@ b632 = makeAggregation(
 b632plus = makeAggregation(
   id = "b632plus",
   name = ".632 Bootstrap plus",
+  properties = c("req.train", "req.test"),
   fun = function(task, perf.test, perf.train, measure, group, pred) {
     df = as.data.frame(pred)
     a = numeric(length(perf.test))
@@ -201,6 +219,7 @@ b632plus = makeAggregation(
 testgroup.mean = makeAggregation(
   id = "testgroup.mean",
   name = "Test group mean",
+  properties = "req.test",
   fun = function(task, perf.test, perf.train, measure, group, pred) {
     mean(vnapply(split(perf.test, group), mean))
   }
@@ -211,12 +230,18 @@ testgroup.mean = makeAggregation(
 test.join = makeAggregation(
   id = "test.join",
   name = "Test join",
+  properties = "req.test",
   fun = function(task, perf.test, perf.train, measure, group, pred) {
     df = as.data.frame(pred)
     f = if (length(group)) group[df$iter] else factor(rep(1L, nrow(df)))
     mean(vnapply(split(df, f), function(df) {
+      if (pred$predict.type == "response") y = df$response
+      if (pred$predict.type == "prob") {
+        y = df[, stri_startswith_fixed(colnames(df), "prob."), drop = FALSE]
+        colnames(y) = stri_sub(colnames(y), 6L)
+      }
       npred = makePrediction(task.desc = pred$task.desc, row.names = rownames(df),
-        id = NULL, truth = df$truth, predict.type = pred$predict.type, y = df$response,
+        id = NULL, truth = df$truth, predict.type = pred$predict.type, y = y,
         time = NA_real_)
       performance(npred, measure)
     }))
