@@ -12,18 +12,21 @@
 learnerArgsToControl = function(control, ...) {
   args = list()
   dots = match.call(expand.dots = FALSE)$...
-  for (arg in dots) {
+  for (i in seq_along(dots)) {
+    arg = dots[[i]]
     is_missing = if (is.symbol(arg)) {
+      argname = as.character(arg)
       eval(substitute(missing(symbol), list(symbol = arg)),
            envir = parent.frame())
     } else {
+      argname = names(dots)[i]
       FALSE
     }
     if (!is_missing) {
       value = tryCatch(eval(arg, envir = parent.frame()),
                        error = function(...) NULL)
       if (!is.null(value)) {
-        args[[as.character(arg)]] = value
+        args[[as.character(argname)]] = value
       }
     }
   }
