@@ -58,14 +58,8 @@ predict.WrappedModel = function(object, task, newdata, subset = NULL, ...) {
     }
     size = nrow(newdata)
   }
-  if (is.null(subset)) {
-    subset = seq_len(size)
-  } else {
-    if (is.logical(subset))
-      subset = which(subset)
-    else
-      subset = asInteger(subset, min.len = 1L, any.missing = FALSE, lower = 1L, upper = size)
-  }
+  subset = checkTaskSubset(subset, size)
+
   if (missing(newdata)) {
     newdata = getTaskData(task, subset)
   } else {
@@ -89,10 +83,13 @@ predict.WrappedModel = function(object, task, newdata, subset = NULL, ...) {
   }
 
   error = NA_character_
+  # default to NULL error dump
+  dump = NULL
   # was there an error in building the model? --> return NAs
   if (isFailureModel(model)) {
     p = predictFailureModel(model, newdata)
     time.predict = NA_real_
+    dump = getFailureModelDump(model)
   } else {
     #FIXME: this copies newdata
     pars = list(
@@ -104,15 +101,18 @@ predict.WrappedModel = function(object, task, newdata, subset = NULL, ...) {
     debug.seed = getMlrOption("debug.seed", NULL)
     if (!is.null(debug.seed))
       set.seed(debug.seed)
-    opts = getLearnerOptions(learner, c("show.learner.output", "on.learner.error", "on.learner.warning"))
+    opts = getLearnerOptions(learner, c("show.learner.output", "on.learner.error", "on.learner.warning", "on.error.dump"))
     fun1 = if (opts$show.learner.output) identity else capture.output
     fun2 = if (opts$on.learner.error == "stop") identity else function(x) try(x, silent = TRUE)
+    fun3 = if (opts$on.learner.error == "stop" || !opts$on.error.dump) identity else function(x) {
+        withCallingHandlers(x, error = function(c) utils::dump.frames())
+      }
     if (opts$on.learner.warning == "quiet") {
       old.warn.opt = getOption("warn")
       on.exit(options(warn = old.warn.opt))
       options(warn = -1L)
     }
-    time.predict = measureTime(fun1(p <- fun2(do.call(predictLearner2, pars))))
+    time.predict = measureTime(fun1({p = fun2(fun3(do.call(predictLearner2, pars)))}))
 
     # was there an error during prediction?
     if (is.error(p)) {
@@ -121,6 +121,9 @@ predict.WrappedModel = function(object, task, newdata, subset = NULL, ...) {
       error = as.character(p)
       p = predictFailureModel(model, newdata)
       time.predict = NA_real_
+      if (opts$on.error.dump) {
+        dump = addClasses(get("last.dump", envir = .GlobalEnv), "mlr.dump")
+      }
     }
   }
   if (missing(task))
@@ -128,5 +131,5 @@ predict.WrappedModel = function(object, task, newdata, subset = NULL, ...) {
   else
     ids = subset
   makePrediction(task.desc = td, row.names = rownames(newdata), id = ids, truth = truth,
-    predict.type = learner$predict.type, predict.threshold = learner$predict.threshold, y = p, time = time.predict, error = error)
+    predict.type = learner$predict.type, predict.threshold = learner$predict.threshold, y = p, time = time.predict, error = error, dump = dump)
 }
