@@ -13,6 +13,8 @@
 #' @export
 setPredictThreshold = function(learner, predict.threshold) {
   learner = checkLearner(learner, type = "classif")
+  if (learner$predict.type != "prob")
+    stopf("predict.type = 'prob' must hold to set a predict.threshold!")
   assertNumeric(predict.threshold, any.missing = FALSE)
   learner$predict.threshold = predict.threshold
   return(learner)
