@@ -1,28 +1,22 @@
 tuneMBO = function(learner, task, resampling, measures, par.set, control,
-  opt.path, show.info) {
+  opt.path, show.info, resample.fun) {
 
-  # requirePackages("mlrMBO", why = "tuneMBO", default.method = "load")
+  requirePackages("mlrMBO", why = "tuneMBO", default.method = "load")
   mbo.control = control$mbo.control
 
-  # set final evals to 0 to save time. we dont really need final evals in this context.
-  mbo.control$final.evals = 0L
-
   # put all required info into the function env
   force(learner); force(task); force(resampling); force(measures); force(par.set); force(control); force(opt.path); force(show.info)
+
   tff = tunerSmoofFun(learner = learner, task = task, resampling = resampling, measures = measures,
     par.set = par.set, ctrl = control, opt.path = opt.path, show.info = show.info,
-    convertx = convertXIdentity, remove.nas = TRUE)
+    convertx = convertXIdentity, remove.nas = TRUE, resample.fun = resample.fun)
 
   state = mbo.control$save.file.path
   if (control$continue && file.exists(state)) {
     messagef("Resuming previous MBO run using state in '%s'...", state)
-    # FIXME: remove this when mbo on cran
-    mbofun = get("mboContinue", envir = getNamespace("mlrMBO"))
-    or = mbofun(state)
+    or = mlrMBO::mboContinue(state)
   } else {
-    # FIXME: remove this when mbo on cran
-    mbofun = get("mbo", envir = getNamespace("mlrMBO"))
-    or = mbofun(tff, design = control$mbo.design, learner = control$learner, control = mbo.control, show.info = FALSE)
+    or = mlrMBO::mbo(tff, design = control$mbo.design, learner = control$learner, control = mbo.control, show.info = FALSE)
   }
 
   x = trafoValue(par.set, or$x)
