@@ -95,9 +95,7 @@ testBasicLearnerProperties = function(lrn, task, hyperpars, pred.type = "respons
       types = "numeric", any.missing = FALSE)
     expect_true(info = info, all(probdf >= 0 && probdf <= 1))
 
-    # FIXME: the "sum to 1" apparently does not work for all learners?
-    # I can see differences up to 0.1 for some cases, reported in issue #1017
-    # expect_equal(info = info, unname(rowSums(probdf)), rep(1, NROW(probdf)), use.names = FALSE)
+    expect_equal(info = info, unname(rowSums(probdf)), rep(1, NROW(probdf)), use.names = FALSE, tolerance = 0.01)
   }
 }
 
@@ -156,6 +154,30 @@ testThatLearnerHandlesMissings = function(lrn, task, hyperpars) {
   testBasicLearnerProperties(lrn = lrn, task = task, hyperpars = hyperpars)
 }
 
+# Test that the extraction of the out-of-bag predictions for the learner that supports 
+# this works correctly
+
+testThatGetOOBPredsWorks = function(lrn, task) {
+  type = lrn$type
+  mod = train(lrn, task)
+  oob = getOOBPreds(mod, task)
+  
+  if (type == "classif") {
+    if(lrn$predict.type == "response") {
+      expect_is(oob$data, "data.frame")
+      expect_equal(levels(oob$data$response), task$task.desc$class.levels)
+    } else {
+      expect_is(oob$data, "data.frame")
+      expect_numeric(getPredictionProbabilities(oob))
+    }
+  } else {
+    if (type %in% c("regr", "surv")) {
+      expect_is(oob$data$response, "numeric")
+    } 
+  }
+  expect_equal(nrow(oob$data), nrow(getTaskData(task)))
+}
+
 testThatLearnerCanCalculateImportance = function(lrn, task, hyperpars) {
 
 
