@@ -1,7 +1,7 @@
 context("getCaretParamSet")
 
 test_that("getCaretParamSet", {
-  requirePackages(c("caret", "rpart", "earth"))
+  requirePackagesOrSkip(c("caret", "rpart", "earth"))
   checkCaretParams = function(lrn, k, task) {
     set.seed(123)
     a = capture.output({cps1 = getCaretParamSet(lrn, length = k, task = task, discretize = TRUE)})
