@@ -4,7 +4,7 @@ test_that("listLearners", {
   x1 = listLearners(create = FALSE, warn.missing.packages = FALSE)
   expect_data_frame(x1, min.rows = 1L, min.cols = 10)
   expect_set_equal(x1$type, c("classif", "regr", "cluster", "surv", "multilabel"))
-  expect_subset(getSupportedLearnerProperties(), names(x1))
+  expect_subset(listLearnerProperties(), names(x1))
 
   x1a = listLearners("classif", create = FALSE, properties = c("missings"), warn.missing.packages = FALSE)
   expect_data_frame(x1a, min.rows = 10)
@@ -27,5 +27,10 @@ test_that("listLearners", {
 
 test_that("listLearners printer (#1336)", {
   x1 = listLearners(create = FALSE, warn.missing.packages = FALSE)
-  capture.output(print(x1), file = NULL)
+  options(width = 1000)
+  out = capture.output(print(x1), file = NULL)
+  expect_equal(length(stri_match_all(out, regex = '\n')), 9)
+  out = capture.output(print(x1, n = 10), file = NULL)
+  expect_equal(length(stri_match_all(out, regex = '\n')), 13)
+  options(width = 80)
 })
