@@ -36,4 +36,12 @@ test_that("plotBMRRanksAsBarChart", {
   doc = XML::xmlParse(path)
   testDocForStrings(doc, getBMRLearnerShortNames(res)[2:1], ordered = TRUE)
 
+   # check error when learner short names are not unique
+  lrns = list(
+    rf = makeLearner("classif.randomForest", id = "rf1"),
+    rf2 = makeLearner("classif.randomForest", id = "rf2")
+  )
+  res = benchmark(lrns, tasks)
+  expect_error(plotBMRSummary(res),
+    "names are not unique")
 })
