@@ -25,5 +25,14 @@ test_that("BenchmarkSummary", {
   ggsave(path)
   doc = XML::xmlParse(path)
   testDocForStrings(doc, getBMRLearnerIds(res))
+
+  # check error when learner short names are not unique
+  lrns = list(
+    rf = makeLearner("classif.randomForest", id = "rf1"),
+    rf2 = makeLearner("classif.randomForest", id = "rf2")
+  )
+  res = benchmark(lrns, tasks, rdesc, meas)
+  expect_error(plotBMRSummary(res),
+    "names are not unique")
   
 })
