@@ -162,5 +162,15 @@ test_that("tuning does not break with small discrete values, see bug in #1115",
   tuneParams("classif.rpart",multiclass.task, hout, par.set = ps, control = ctrl)
 })
 
-
+test_that("tuning works with large param.sets", {
+  lrn = makeLearner("classif.__mlrmocklearners__5")
+  ctrl = makeTuneControlRandom(maxit=3)
+  # create long list of learner params
+  psLength = 200
+  longLearnerParams = do.call(base::c, lapply(seq_len(psLength), function(x) {
+    makeParamSet(makeIntegerLearnerParam(paste0('some.parameter', x), 1, 10))
+  }))
+  lrn$par.set = c(lrn$par.set, longLearnerParams)
+  tuneParams(lrn, pid.task, cv5, par.set = longLearnerParams, control = ctrl, show.info=TRUE)
+})
 
