@@ -1,7 +1,8 @@
 context("classif_PART")
 
 test_that("classif_PART", {
-  requirePackages("RWeka", default.method = "load")
+  requirePackagesOrSkip("RWeka", default.method = "load")
+
   parset.list = list(
     list(),
     list(M = 10),
