@@ -33,7 +33,7 @@ test_that("classif_blackboost", {
     set.seed(getOption("mlr.debug.seed"))
     old.predicts.list[[i]] = predict(m, newdata = binaryclass.test, type = "class")
     set.seed(getOption("mlr.debug.seed"))
-    old.probs.list[[i]] = predict(m, newdata = binaryclass.test, type = "response")[,1]
+    old.probs.list[[i]] = 1 - predict(m, newdata = binaryclass.test, type = "response")[,1]
   }
 
   testSimpleParsets("classif.blackboost", binaryclass.df, binaryclass.target,
