@@ -7,16 +7,16 @@ test_that("regr_bgp", {
     list(),
     list(meanfn = "linear", bprior = "bflat", corr = "expsep")
   )
-  inds = 1:10
-  y = regr.df[inds, regr.target]
+  inds = 1:50
+  y = regr.num.df[inds, regr.num.target]
   old.predicts.list = list()
   for (i in 1:length(parset.list)) {
     parset = parset.list[[i]]
-    pars = list(X = regr.df[inds, 1:3], Z = y, verb = 0, pred.n = FALSE)
+    pars = list(X = regr.num.df[inds, -regr.num.class.col], Z = y, verb = 0, pred.n = FALSE)
     pars = c(pars, parset)
     set.seed(getOption("mlr.debug.seed"))
     m = do.call(tgp::bgp, pars)
-    old.predicts.list[[i]] = predict(m, XX = regr.df[-inds, 1:3], pred.n = FALSE)$ZZ.km
+    old.predicts.list[[i]] = predict(m, XX = regr.num.df[-inds, -regr.num.class.col], pred.n = FALSE)$ZZ.km
   }
-  testSimpleParsets("regr.bgp", regr.df[, c(1:3, 14)], regr.target, inds, old.predicts.list, parset.list)
+  testSimpleParsets("regr.bgp", regr.num.df, regr.num.target, inds, old.predicts.list, parset.list)
 })
