@@ -1,7 +1,8 @@
 context("regr_cubist")
 
 test_that("regr_cubist", {
-  requirePackages("Cubist", default.method = "load")
+  requirePackagesOrSkip("Cubist", default.method = "load")
+
   parset.list1 = list(
     list(),
     list(committees = 2L),
