@@ -5,7 +5,7 @@ test_that("regr_glmnet", {
 
   parset.list = list(
     list(),
-    list(alpha = 0.7),
+    list(alpha = 0.7, fdev = 0.0001),
     list(s = 0.3)
   )
 
@@ -22,12 +22,13 @@ test_that("regr_glmnet", {
     y = regr.train[, ind]
     pars = list(x = as.matrix(x), y = y, family = "gaussian")
     pars = c(pars, parset)
+    glmnet::glmnet.control(factory = TRUE)
     ctrl.args = names(formals(glmnet::glmnet.control))
     set.seed(getOption("mlr.debug.seed"))
     if (any(names(pars) %in% ctrl.args)) {
-      do.call(glmnet.control, pars[names(pars) %in% ctrl.args])
-      m = do.call(glmnet, pars[!names(pars) %in% ctrl.args])
-      glmnet::glmnet.control(factory = TRUE)
+      on.exit(glmnet::glmnet.control(factory = TRUE))
+      do.call(glmnet::glmnet.control, pars[names(pars) %in% ctrl.args])
+      m = do.call(glmnet::glmnet, pars[!names(pars) %in% ctrl.args])
     } else {
       m = do.call(glmnet::glmnet, pars)
     }
