@@ -10,7 +10,7 @@ test_that("regr_rknn", {
   parset.list = apply(parset.grid, MARGIN = 1L, as.list)
   #rknn needs integer seed for reproducibility
   parset.list = lapply(parset.list, function(x) c(x, seed = 2015L))
-
+  parset.list = c(parset.list, list(list(seed = 2015L))) # to test empty paramset
   old.predicts.list = list()
 
   for (i in 1L:length(parset.list)) {
@@ -28,6 +28,8 @@ test_that("regr_rknn", {
 
   testSimpleParsets("regr.rknn", regr.num.df, regr.num.target, regr.num.train.inds,
                     old.predicts.list, parset.list)
+  
+  parset.list[[9]] = NULL
 
   tt = function (formula, data, k = 1L, r = 500L, mtry = 2L, seed = 2015L, cluster = NULL) {
     return(list(formula = formula, data = data, k = k, r = r, mtry = mtry,
