@@ -15,18 +15,18 @@ test_that("regr_xgboost", {
     if (is.null(parset$verbose)) parset$verbose = 0L
     if (is.null(parset$nrounds)) parset$nrounds = 1L
     if (is.null(parset$objective)) parset$objective = "reg:linear"
-    pars = list(data = data.matrix(regr.train[,1:13]), label = as.numeric(regr.train[,14]))
+    pars = list(data = data.matrix(regr.num.train[,-regr.num.class.col]), label = as.numeric(regr.num.train[,regr.num.class.col]))
     pars = c(pars, parset)
     set.seed(getOption("mlr.debug.seed"))
     model = do.call(xgboost::xgboost, pars)
-    #model = xgboost::xgboost(data = data.matrix(regr.train[,1:13]), verbose = 0L,
-    #label = as.numeric(regr.train[,14]),
+    #model = xgboost::xgboost(data = data.matrix(regr.num.train[,-regr.num.class.col]), verbose = 0L,
+    #label = as.numeric(regr.num.train[,regr.num.class.col]),
     #nrounds = 20, objective = "reg:linear", missing = NULL)
-    old.predicts.list[[i]] = predict(model, data.matrix(regr.test[,1:13]))
+    old.predicts.list[[i]] = predict(model, data.matrix(regr.num.test[,-regr.num.class.col]))
   }
   
   #set.seed(getOption("mlr.debug.seed"))
-  testSimpleParsets("regr.xgboost", regr.df, regr.target, regr.train.inds,
+  testSimpleParsets("regr.xgboost", regr.num.df, regr.num.target, regr.num.train.inds,
     old.predicts.list, parset.list)
 })
 
