@@ -1,7 +1,8 @@
 context("regr_xyf")
 
 test_that("regr_xyf", {
-  requirePackages("kohonen", default.method = "load")
+  requirePackagesOrSkip("kohonen", default.method = "load")
+
   parset.list1 = list(
     list(),
     list(grid = class::somgrid(xdim = 2L, ydim = 4L)),
