@@ -1,7 +1,8 @@
 context("surv_CoxBoost")
 
 test_that("surv_CoxBoost", {
-  requirePackages(c("!Matrix", "CoxBoost"), default.method = "load")
+  requirePackagesOrSkip(c("!Matrix", "!CoxBoost"), default.method = "load")
+
   parset.list = list(
     list(),
     list(stepno = 10)
