@@ -132,4 +132,30 @@ test_that("plotTuneMultiCritResult works with pretty.names", {
     list(mmce, acc), par.set = ps, control = ctrl.grid)
   plotTuneMultiCritResult(opt.multi.crit)
   plotTuneMultiCritResult(opt.multi.crit, pretty.names = FALSE)
-})
\ No newline at end of file
+})
+
+test_that("tuneParamsMultiCrit with resample.fun", {
+  lrn =  makeLearner("classif.rpart")
+  rdesc = makeResampleDesc("Holdout")
+  ps = makeParamSet(
+    makeIntegerParam("minsplit", lower=1, upper = 50)
+  )
+
+  # random search
+  ctrl = makeTuneMultiCritControlRandom(maxit = 2)
+  res = tuneParamsMultiCrit(lrn, binaryclass.task, rdesc, par.set = ps,
+    measures = list(tpr, fpr), control = ctrl, resample.fun = constant05Resample)
+  expect_true(all(getOptPathY(res$opt.path) == 0.5))
+
+  # grid search
+  ctrl = makeTuneMultiCritControlGrid(resolution = 2L)
+  res = tuneParamsMultiCrit(lrn, binaryclass.task, rdesc, par.set = ps,
+    measures = list(tpr, fpr), control = ctrl, resample.fun = constant05Resample)
+  expect_true(all(getOptPathY(res$opt.path) == 0.5))
+
+  # nsga2
+  ctrl = makeTuneMultiCritControlNSGA2(popsize = 4L, generations = 1L)
+  res = tuneParamsMultiCrit(lrn, binaryclass.task, rdesc, par.set = ps,
+    measures = list(tpr, fpr), control = ctrl, resample.fun = constant05Resample)
+  expect_true(all(getOptPathY(res$opt.path) == 0.5))
+})
